#ifndef VICIOUS_H
#define VICIOUS_H

#include "ve-misc.h"
#include "ve-config.h"
#include "ve-signal.h"

#endif /* VICIOUS_H */
